@@ -3,11 +3,14 @@
 use strict;
 use Encode;
 use Parse::AFP;
+use File::Path 'rmtree';
 
-die "Usage: $0 input.afp dir\n" unless @ARGV == 2;
+die "Usage: $0 input.afp dir\n" unless @ARGV >= 1;
 
 my $input = shift;
-my $output = shift;
+my $output = shift || 'dir';
+
+rmtree([ $output ]) if -d $output;
 
 mkdir $output;
 my $afp = Parse::AFP->new($input, { lazy => 1 });
